NeMo TTS Collection: Neural Modules for Speech Synthesis
========================================================

**Models**

The NeMo TTS collection currently has modules for building
1. Tacotron 2
2. Waveglow

See the documentation and tutorials for ``nemo_tts`` [here](https://nvidia.github.io/NeMo/tts/intro.html).
